# HuggingFaceApi

[![Stable](https://img.shields.io/badge/docs-stable-blue.svg)](https://chengchingwen.github.io/HuggingFaceApi.jl/stable)
[![Dev](https://img.shields.io/badge/docs-dev-blue.svg)](https://chengchingwen.github.io/HuggingFaceApi.jl/dev)
[![Build Status](https://github.com/chengchingwen/HuggingFaceApi.jl/workflows/CI/badge.svg)](https://github.com/chengchingwen/HuggingFaceApi.jl/actions)
[![Coverage](https://codecov.io/gh/chengchingwen/HuggingFaceApi.jl/branch/master/graph/badge.svg)](https://codecov.io/gh/chengchingwen/HuggingFaceApi.jl)

Pure Julia [Huggingface api](https://github.com/huggingface/huggingface_hub)


# Example

## Basic usage

```julia
julia> using HuggingFaceApi

julia> file = hf_hub_download("lysandre/arxiv-nlp", "config.json");

# or equivalent to
julia> url = HuggingFaceURL("lysandre/arxiv-nlp", "config.json")
HuggingFaceURL(https://huggingface.co/lysandre/arxiv-nlp/resolve/main/config.json)

julia> file = HuggingFaceApi.cached_download(url);

julia> readlines(file)
29-element Vector{String}:
 "{"
 "  \"_num_labels\": 1,"
 "  \"activation_function\": \"gelu_new\","
 "  \"attn_pdrop\": 0.1,"
 ⋮
 "  \"summary_type\": \"token_ids\","
 "  \"summary_use_proj\": true,"
 "  \"vocab_size\": 50257"
 "}"

# remove cached file if don't need it anymore
julia> HuggingFaceApi.remove_cache(url; now=true)
[ Info: 1 MyArtifact deleted (604.000 byte)


```

## Download from private repo

```julia
julia> using HuggingFaceApi

julia> HuggingFaceApi.login("chengchingwen");
password: 

julia> private_file = HuggingFaceApi.hf_hub_download("chengchingwen/test_model_repo", "README.md");

julia> readlines(private_file)
1-element Vector{String}:
 "TEST THIS private repo"

julia> HuggingFaceApi.logout()

```

